@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -83,7 +83,6 @@ all
 
 <install_package_names>
 cinnamon-desktop-environment
-elogind
 </install_package_names>
 
 
