@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Czech_LO_full
    <ja>チェコ語のLibreOffice言語メタパッケージ</ja>
    <kk>Czech LibreOffice Language Meta-Package</kk>
    <ko>Czech LibreOffice Language Meta-Package</ko>
+   <ku>Czech LibreOffice Language Meta-Package</ku>
    <lt>Czech LibreOffice Language Meta-Package</lt>
    <mk>Czech LibreOffice Language Meta-Package</mk>
    <mr>Czech LibreOffice Language Meta-Package</mr>
@@ -49,6 +50,7 @@ Czech_LO_full
    <nb>Tsjekkisk språkpakke for LibreOffice</nb>
    <nl_BE>Czech LibreOffice Language Meta-Package</nl_BE>
    <nl>Tjechische LibreOffice Taal Meta-Pakket</nl>
+   <or>Czech LibreOffice Language Meta-Package</or>
    <pl>Czeski metapakiet językowy dla LibreOffice</pl>
    <pt_BR>Checo Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Checo Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Czech_LO_full
    <ru>Czech LibreOffice Language Meta-Package</ru>
    <sk>Czech LibreOffice Language Meta-Package</sk>
    <sl>Češki jezikovni metapaket za LibreOffice</sl>
+   <so>Czech LibreOffice Language Meta-Package</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në çekisht</sq>
    <sr>Czech LibreOffice Language Meta-Package</sr>
    <sv>Tjeckisk LibreOffice Språk Meta-Paket</sv>
