@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Scottish_LO_full
    <ja>LibreOffice用の高地スコットランド・ゲール語メタパッケージ</ja>
    <kk>Scottish_gaelic Language Meta-Package for LibreOffice</kk>
    <ko>Scottish_gaelic Language Meta-Package for LibreOffice</ko>
+   <ku>Scottish_gaelic Language Meta-Package for LibreOffice</ku>
    <lt>Scottish_gaelic Language Meta-Package for LibreOffice</lt>
    <mk>Scottish_gaelic Language Meta-Package for LibreOffice</mk>
    <mr>Scottish_gaelic Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Scottish_LO_full
    <nb>Skotsk-gælisk språkpakke for LibreOffice</nb>
    <nl_BE>Scottish_gaelic Language Meta-Package for LibreOffice</nl_BE>
    <nl>Schots-Gaelic Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Scottish_gaelic Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka gaelickiego szkockiego dla LibreOffice</pl>
    <pt_BR>Gaélico Escocês Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Gaélico_escocês Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Scottish_LO_full
    <ru>Scottish_gaelic Language Meta-Package for LibreOffice</ru>
    <sk>Scottish_gaelic Language Meta-Package for LibreOffice</sk>
    <sl>Škotsko gelške jezikovni meta-paket za LibreOffice</sl>
+   <so>Scottish_gaelic Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në gaelike skoceze</sq>
    <sr>Scottish_gaelic Language Meta-Package for LibreOffice</sr>
    <sv>Skottsk_gaelic Språk Meta-Paket för LibreOffice</sv>
