@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -78,12 +78,12 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "deb http://deb.debian.org/debian buster-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
+echo "deb http://deb.debian.org/debian bullseye-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
 apt-get update
 </preinstall>
 
 <install_package_names>
--t buster-backports libreoffice-base-core
+-t bullseye-backports libreoffice-base-core
 libreoffice-calc
 libreoffice-draw
 libreoffice-impress
@@ -92,6 +92,7 @@ libreoffice-writer
 libreoffice-base
 libreoffice-gtk3
 libreoffice-l10n-ug
+libreoffice-java-common
 </install_package_names>
 
 <postinstall>
@@ -107,6 +108,7 @@ libreoffice-impress
 libreoffice-math
 libreoffice-writer
 libreoffice-base
+libreoffice-java-common
 libreoffice-gtk3
 libreoffice-l10n-ug
 </uninstall_package_names>
