@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Uzbek_LO_full
    <ja>LibreOffice用のウズベク語メタパッケージ</ja>
    <kk>Uzbek Language Meta-Package for LibreOffice</kk>
    <ko>Uzbek Language Meta-Package for LibreOffice</ko>
+   <ku>Uzbek Language Meta-Package for LibreOffice</ku>
    <lt>Uzbek Language Meta-Package for LibreOffice</lt>
    <mk>Uzbek Language Meta-Package for LibreOffice</mk>
    <mr>Uzbek Language Meta-Package for LibreOffice</mr>
@@ -49,6 +50,7 @@ Uzbek_LO_full
    <nb>Uzbekisk språkpakke for LibreOffice</nb>
    <nl_BE>Uzbek Language Meta-Package for LibreOffice</nl_BE>
    <nl>Oezbeekse Taal Meta-Pakket voor LibreOffice</nl>
+   <or>Uzbek Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka uzbeckiego dla LibreOffice</pl>
    <pt_BR>Usbeque Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Uzbeque Meta-Pacote de Idioma para LibreOffice</pt>
@@ -56,6 +58,7 @@ Uzbek_LO_full
    <ru>Uzbek Language Meta-Package for LibreOffice</ru>
    <sk>Uzbek Language Meta-Package for LibreOffice</sk>
    <sl>Uzbeški jezikovni meta-paket za LibreOffice</sl>
+   <so>Uzbek Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në uzbeke</sq>
    <sr>Uzbek Language Meta-Package for LibreOffice</sr>
    <sv>Uzbekiskt Språk Meta-Paket för LibreOffice</sv>
