@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ MATE
    <ja>MATE デスクトップの基本インストール</ja>
    <kk>basic install of MATE desktop</kk>
    <ko>basic install of MATE desktop</ko>
+   <ku>basic install of MATE desktop</ku>
    <lt>basic install of MATE desktop</lt>
    <mk>basic install of MATE desktop</mk>
    <mr>basic install of MATE desktop</mr>
@@ -49,6 +50,7 @@ MATE
    <nb>grunnleggende installasjon av skrivebordsmiljøet MATE</nb>
    <nl_BE>basic install of MATE desktop</nl_BE>
    <nl>basisinstallatie van de MATE desktop</nl>
+   <or>basic install of MATE desktop</or>
    <pl>podstawowa instalacja środowiska MATE</pl>
    <pt_BR>Instalação Básica do Ambiente de Trabalho MATE</pt_BR>
    <pt>Instalação básica do Ambiente de Trabalho MATE</pt>
@@ -56,6 +58,7 @@ MATE
    <ru>Базовая установка окружения MATE</ru>
    <sk>basic install of MATE desktop</sk>
    <sl>Osnovna namestitev MATE namizja</sl>
+   <so>basic install of MATE desktop</so>
    <sq>Instalim elementar i desktopit MATE</sq>
    <sr>basic install of MATE desktop</sr>
    <sv>enkel installation av MATE skrivbord</sv>
@@ -81,7 +84,6 @@ all
 <install_package_names>
 mate-core
 mate-desktop-environment
-elogind
 gvfs
 </install_package_names>
 
